@@ -119,7 +119,7 @@ class TestListenerCreate(TestListener):
             ('loadbalancer', 'mock_lb_id'),
             ('name', self._listener.name),
             ('protocol', 'HTTP'),
-            ('protocol_port', 80)
+            ('protocol_port', '80')
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -138,15 +138,26 @@ class TestListenerCreate(TestListener):
                    self._listener.sni_container_refs[0],
                    self._listener.sni_container_refs[1],
                    '--default-tls-container-ref',
-                   self._listener.default_tls_container_ref]
+                   self._listener.default_tls_container_ref,
+                   '--client-ca-tls-container-ref',
+                   self._listener.client_ca_tls_container_ref,
+                   '--client-authentication',
+                   self._listener.client_authentication,
+                   '--client-crl-container-ref',
+                   self._listener.client_crl_container_ref]
         verifylist = [
             ('loadbalancer', 'mock_lb_id'),
             ('name', self._listener.name),
             ('protocol', 'TERMINATED_HTTPS'),
-            ('protocol_port', 443),
+            ('protocol_port', '443'),
             ('sni_container_refs', self._listener.sni_container_refs),
             ('default_tls_container_ref',
-             self._listener.default_tls_container_ref)
+             self._listener.default_tls_container_ref),
+            ('client_ca_tls_container_ref',
+             self._listener.client_ca_tls_container_ref),
+            ('client_authentication', self._listener.client_authentication),
+            ('client_crl_container_ref',
+             self._listener.client_crl_container_ref)
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -169,7 +180,7 @@ class TestListenerCreate(TestListener):
             ('loadbalancer', 'mock_lb_id'),
             ('name', self._listener.name),
             ('protocol', 'HTTP'),
-            ('protocol_port', 80),
+            ('protocol_port', '80'),
             ('timeout_client_data', 123),
             ('timeout_member_connect', 234),
             ('timeout_member_data', 345),
@@ -216,13 +227,25 @@ class TestListenerSet(TestListener):
                    self._listener.sni_container_refs[0],
                    self._listener.sni_container_refs[1],
                    '--default-tls-container-ref',
-                   self._listener.default_tls_container_ref]
+                   self._listener.default_tls_container_ref,
+                   '--client-ca-tls-container-ref',
+                   self._listener.client_ca_tls_container_ref,
+                   '--client-authentication',
+                   self._listener.client_authentication,
+                   '--client-crl-container-ref',
+                   self._listener.client_crl_container_ref]
         verifylist = [
             ('listener', self._listener.id),
             ('name', 'new_name'),
             ('sni_container_refs', self._listener.sni_container_refs),
             ('default_tls_container_ref',
-                self._listener.default_tls_container_ref)
+                self._listener.default_tls_container_ref),
+            ('client_ca_tls_container_ref',
+             self._listener.client_ca_tls_container_ref),
+            ('client_authentication',
+             self._listener.client_authentication),
+            ('client_crl_container_ref',
+             self._listener.client_crl_container_ref)
         ]
 
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -233,7 +256,13 @@ class TestListenerSet(TestListener):
                     'name': 'new_name',
                     'sni_container_refs': self._listener.sni_container_refs,
                     'default_tls_container_ref':
-                        self._listener.default_tls_container_ref
+                        self._listener.default_tls_container_ref,
+                    'client_ca_tls_container_ref':
+                        self._listener.client_ca_tls_container_ref,
+                    'client_authentication':
+                        self._listener.client_authentication,
+                    'client_crl_container_ref':
+                        self._listener.client_crl_container_ref
                 }})
 
 
